<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID je izmenjen",
"Invalid request" => "Neispravan zahtev",
"Language changed" => "Jezik je izmenjen",
"Select an App" => "Izaberite program",
"Ask a question" => "Postavite pitanje",
"Problems connecting to help database." => "Problem u povezivanju sa bazom pomoći",
"Go there manually." => "Otiđite tamo ručno.",
"Answer" => "Odgovor",
"Unable to change your password" => "Ne mogu da izmenim vašu lozinku",
"Current password" => "Trenutna lozinka",
"New password" => "Nova lozinka",
"show" => "prikaži",
"Change password" => "Izmeni lozinku",
"Language" => "Jezik",
"use this address to connect to your ownCloud in your file manager" => "koristite ovu adresu da bi se povezali na ownCloud putem menadžnjera fajlova",
"Name" => "Ime",
"Password" => "Lozinka",
"Groups" => "Grupe",
"Create" => "Napravi",
"Delete" => "Obriši"
);
